Enum Request

#[non_exhaustive]
pub enum Request<'a> { StartDrag { source: Option<WlDataSource>, origin: WlSurface, icon: Option<WlSurface>, serial: u32, }, SetSelection { source: Option<WlDataSource>, serial: u32, }, Release, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


StartDrag

start drag-and-drop operation

This request asks the compositor to start a drag-and-drop operation on behalf of the client.

The source argument is the data source that provides the data for the eventual data transfer. If source is NULL, enter, leave and motion events are sent only to the client that initiated the drag and the client is expected to handle the data passing internally. If source is destroyed, the drag-and-drop session will be cancelled.

The origin surface is the surface where the drag originates and the client must have an active implicit grab that matches the serial.

The icon surface is an optional (can be NULL) surface that provides an icon to be moved around with the cursor. Initially, the top-left corner of the icon surface is placed at the cursor hotspot, but subsequent wl_surface.offset requests can move the relative position. Attach requests must be confirmed with wl_surface.commit as usual. The icon surface is given the role of a drag-and-drop icon. If the icon surface already has another role, it raises a protocol error.

The input region is ignored for wl_surfaces with the role of a drag-and-drop icon.

The given source may not be used in any further set_selection or start_drag requests. Attempting to reuse a previously-used source may send a used_source error.

Fields

source: Option<WlDataSource>

data source for the eventual transfer

origin: WlSurface

surface where the drag originates

icon: Option<WlSurface>

drag-and-drop icon surface

serial: u32

serial number of the implicit grab on the origin



SetSelection

copy data to the selection

This request asks the compositor to set the selection to the data from the source on behalf of the client.

To unset the selection, set the source to NULL.

The given source may not be used in any further set_selection or start_drag requests. Attempting to reuse a previously-used source may send a used_source error.

Fields

source: Option<WlDataSource>

data source for the selection

serial: u32

serial number of the event that triggered this request



Release

destroy data device

This request destroys the data device.

This is a destructor, once sent this object cannot be used any longer. Only available since version 2 of the interface

Implementations



impl<'a> Request<'a>

pub fn opcode(&self) -> u16

Get the opcode number of this message